dumpui

package
v3.1.0-beta.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 18, 2025 License: GPL-3.0 Imports: 5 Imported by: 0

Documentation

Overview

Package dumpui provides a universal wizard for running dump-family commands.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Wizard

type Wizard struct {
	// Title is the title of the command.
	Title string
	// Name is the name of the command.
	Name string
	// LocalConfig should return a configuration for the command.
	LocalConfig func() cfgui.Configuration
	// ArgsFn should return a slice of arguments to pass to the command.
	ArgsFn func() []string
	// ValidateParamsFn should return true if the parameters are OK.
	ValidateParamsFn func() error
	// Cmd is the command to run.
	Cmd *base.Command
	// Help is the markdown help text.
	Help string
}

Wizard is a universal wizard for running dump-family commands.

func (*Wizard) Run

func (w *Wizard) Run(ctx context.Context) error

Jump to