Documentation
¶
Overview ¶
Package dumpui provides a universal wizard for running dump-family commands.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Wizard ¶
type Wizard struct {
// Title is the title of the command.
Title string
// Name is the name of the command.
Name string
// LocalConfig should return a configuration for the command.
LocalConfig func() cfgui.Configuration
// ArgsFn should return a slice of arguments to pass to the command.
ArgsFn func() []string
// ValidateParamsFn should return true if the parameters are OK.
ValidateParamsFn func() error
// Cmd is the command to run.
Cmd *base.Command
// Help is the markdown help text.
Help string
}
Wizard is a universal wizard for running dump-family commands.
Click to show internal directories.
Click to hide internal directories.