Documentation
¶
Overview ¶
Package redownload contains redownload logic.
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ErrNoChannels = errors.New("no channels found")
Functions ¶
This section is empty.
Types ¶
type Redownloader ¶
type Redownloader struct {
// contains filtered or unexported fields
}
func New ¶
New initialises the new Redownloader for the given directory. Source type is detected automatically. It validates if the source is of the supported type and returns any errors.
func (*Redownloader) Download ¶
func (r *Redownloader) Download(ctx context.Context, cl fileproc.FileGetter) (FileStats, error)
Click to show internal directories.
Click to hide internal directories.